@@ -7,7 +7,6 @@ model_parameters.selection <- function(model,
                                        standardize = NULL,
                                        exponentiate = FALSE,
                                        p_adjust = NULL,
-                                       summary = getOption("parameters_summary", FALSE),
                                        include_info = getOption("parameters_info", FALSE),
                                        keep = NULL,
                                        drop = NULL,
@@ -18,12 +17,6 @@ model_parameters.selection <- function(model,
     c("all", "selection", "outcome", "auxiliary")
   )
 
-  ## TODO remove deprecated later
-  if (!missing(summary)) {
-    .deprecated_warning("summary", "include_info", verbose)
-    include_info <- summary
-  }
-
   out <- .model_parameters_generic(
     model = model,
     ci = ci,
@@ -46,20 +39,23 @@ model_parameters.selection <- function(model,
 
 
 #' @export
-p_value.selection <- function(model, component = c("all", "selection", "outcome", "auxiliary"), ...) {
-  component <- match.arg(component)
+p_value.selection <- function(model, component = "all", ...) {
+  component <- insight::validate_argument(
+    component,
+    c("all", "selection", "outcome", "auxiliary")
+  )
   s <- summary(model)
   rn <- row.names(s$estimate)
   estimates <- as.data.frame(s$estimate, row.names = FALSE)
   params <- data.frame(
     Parameter = rn,
     p = estimates[[4]],
-    Component = "auxiliary",
+    Component = "selection",
     stringsAsFactors = FALSE,
     row.names = NULL
   )
-  params$Component[s$param$index$betaS] <- "selection"
-  params$Component[s$param$index$betaO] <- "outcome"
+  params$Component[s$param$index$errTerms] <- "auxiliary"
+  params$Component[s$param$index$outcome] <- "outcome"
 
   if (component != "all") {
     params <- params[params$Component == component, , drop = FALSE]
@@ -70,20 +66,23 @@ p_value.selection <- function(model, component = c("all", "selection", "outcome"
 
 
 #' @export
-standard_error.selection <- function(model, component = c("all", "selection", "outcome", "auxiliary"), ...) {
-  component <- match.arg(component)
+standard_error.selection <- function(model, component = "all", ...) {
+  component <- insight::validate_argument(
+    component,
+    c("all", "selection", "outcome", "auxiliary")
+  )
   s <- summary(model)
   rn <- row.names(s$estimate)
   estimates <- as.data.frame(s$estimate, row.names = FALSE)
   params <- data.frame(
     Parameter = rn,
     SE = estimates[[2]],
-    Component = "auxiliary",
+    Component = "selection",
     stringsAsFactors = FALSE,
     row.names = NULL
   )
-  params$Component[s$param$index$betaS] <- "selection"
-  params$Component[s$param$index$betaO] <- "outcome"
+  params$Component[s$param$index$errTerms] <- "auxiliary"
+  params$Component[s$param$index$outcome] <- "outcome"
 
   if (component != "all") {
     params <- params[params$Component == component, , drop = FALSE]
@@ -96,9 +95,12 @@ standard_error.selection <- function(model, component = c("all", "selection", "o
 #' @export
 simulate_model.selection <- function(model,
                                      iterations = 1000,
-                                     component = c("all", "selection", "outcome", "auxiliary"),
+                                     component = "all",
                                      ...) {
-  component <- match.arg(component)
+  component <- insight::validate_argument(
+    component,
+    c("all", "selection", "outcome", "auxiliary")
+  )
   out <- .simulate_model(model, iterations, component = component, effects = "fixed", ...)
 
   class(out) <- c("parameters_simulate_model", class(out))
