@@ -164,8 +164,6 @@ standardize_info.default <- function(model,
 }
 
 
-
-
 # Predictors - Smart ------------------------------------------------------------
 
 
@@ -204,7 +202,6 @@ standardize_info.default <- function(model,
 }
 
 
-
 #' @keywords internal
 .std_info_predictor_smart <- function(data,
                                       variable,
@@ -295,9 +292,6 @@ standardize_info.default <- function(model,
 }
 
 
-
-
-
 # Predictors - sdy ------------------------------------------------------------
 
 
@@ -322,9 +316,6 @@ standardize_info.default <- function(model,
 }
 
 
-
-
-
 # Response ------------------------------------------------------------
 
 #' @keywords internal
@@ -372,7 +363,6 @@ standardize_info.default <- function(model,
 }
 
 
-
 #' @keywords internal
 .std_info_response_basic <- function(model, info, params, robust = FALSE, w = NULL, ...) {
   if (inherits(model, c("gls", "lme"))) {
@@ -404,7 +394,6 @@ standardize_info.default <- function(model,
 }
 
 
-
 # Pseudo (GLMM) -----------------------------------------------------------
 
 .std_info_pseudo <- function(model,
@@ -426,7 +415,8 @@ standardize_info.default <- function(model,
 
   f <- if (two_sd) 2 else 1
 
-  within_vars <- unclass(performance::check_heterogeneity_bias(model))
+  gv <- performance::check_group_variation(model)
+  within_vars <- gv[gv$Variation %in% c("both", "within"), "Variable"]
   id <- insight::get_random(model)[[1]]
   w <- insight::get_weights(model, remove_na = TRUE)
 
@@ -552,7 +542,6 @@ standardize_info.default <- function(model,
 }
 
 
-
 # Utils -------------------------------------------------------------------
 
 
