@@ -519,6 +519,23 @@ format.parameters_standardized <- function(x,
 }
 
 
+#' @export
+display.parameters_standardized <- function(object,
+                                            format = "markdown",
+                                            digits = 2,
+                                            ...) {
+  format <- insight::validate_argument(format, c("markdown", "html", "md", "tt"))
+  fun_args <- list(x = object, digits = digits)
+
+  if (format %in% c("html", "tt")) {
+    fun_args$backend <- format
+    do.call(print_html, c(fun_args, list(...)))
+  } else {
+    do.call(print_md, c(fun_args, list(...)))
+  }
+}
+
+
 #' @export
 print.parameters_standardized <- function(x, digits = 2, ...) {
   x_fmt <- format(x, digits = digits, output = "text", ...)
@@ -534,8 +551,11 @@ print_md.parameters_standardized <- function(x, digits = 2, ...) {
 
 #' @export
 print_html.parameters_standardized <- function(x, digits = 2, ...) {
+  # which engine?
+  engine <- .check_format_backend(...)
+
   x_fmt <- format(x, digits = digits, output = "html", ...)
-  insight::export_table(x_fmt, format = "html", ...)
+  insight::export_table(x_fmt, format = engine, ...)
 }
 
 
